==> SQLMatches-0.0.6.tar.gz: SQLMatches-0.0.6/SQLMatches/api/__init__.py <==
# -*- coding: utf-8 -*-

"""
GNU General Public License v3.0 (GPL v3)
Copyright (c) 2020-2020 WardPearce
Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the "Software"),
to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense,
and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
DEALINGS IN THE SOFTWARE.
"""


from starlette.responses import JSONResponse


def error_response(error: str, **kwargs) -> JSONResponse:
    """
    Handles errors within the api.

    Paramters
    ---------
    error_code: str
        If expection, just use the name of that.
    """

    if "status_code" not in kwargs:
        kwargs["status_code"] = 500

    return JSONResponse({"data": None, "error": error}, **kwargs)


def response(data: dict = None) -> JSONResponse:
    """
    Handles a successful api response.

    Paramters
    ---------
    data: dict
        Data to respond.
    """

    return JSONResponse({"data": data, "error": False})

==> SQLMatches-0.0.9.tar.gz: SQLMatches-0.0.9/SQLMatches/api/__init__.py <==
# -*- coding: utf-8 -*-

"""
GNU General Public License v3.0 (GPL v3)
Copyright (c) 2020-2020 WardPearce
Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the "Software"),
to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense,
and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
DEALINGS IN THE SOFTWARE.
"""


from starlette.responses import JSONResponse


def error_response(error: str, **kwargs) -> JSONResponse:
    """
    Handles errors within the api.

    Paramters
    ---------
    error_code: str
        If expection, just use the name of that.
    """

    if "status_code" not in kwargs:
        kwargs["status_code"] = 500

    return JSONResponse({"data": None, "error": error}, **kwargs)


def response(data: dict = None, **kwargs) -> JSONResponse:
    """
    Handles a successful api response.

    Paramters
    ---------
    data: dict
        Data to respond.
    """

    return JSONResponse({"data": data, "error": False}, **kwargs)
